==> eam-wshub-proxyclient-11.4-8-sources.jar: net/datastream/schemas/mp_fields/TURNAROUND_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;
import org.openapplications.oagis_segments.QUANTITY;


/**
 * <p>Classe Java pour TURNAROUND_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="TURNAROUND_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}TURNAROUNDUOM"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}TURNAROUNDVALUE"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "TURNAROUND_Type", propOrder = {
    "turnarounduom",
    "turnaroundvalue"
})
public class TURNAROUND_Type {

    @XmlElement(name = "TURNAROUNDUOM", required = true)
    protected TURNAROUNDUOM turnarounduom;
    @XmlElement(name = "TURNAROUNDVALUE", required = true)
    protected QUANTITY turnaroundvalue;

    /**
     * Obtient la valeur de la propriété turnarounduom.
     * 
     * @return
     *     possible object is
     *     {@link TURNAROUNDUOM }
     *     
     */
    public TURNAROUNDUOM getTURNAROUNDUOM() {
        return turnarounduom;
    }

    /**
     * Définit la valeur de la propriété turnarounduom.
     * 
     * @param value
     *     allowed object is
     *     {@link TURNAROUNDUOM }
     *     
     */
    public void setTURNAROUNDUOM(TURNAROUNDUOM value) {
        this.turnarounduom = value;
    }

    /**
     * Obtient la valeur de la propriété turnaroundvalue.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getTURNAROUNDVALUE() {
        return turnaroundvalue;
    }

    /**
     * Définit la valeur de la propriété turnaroundvalue.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setTURNAROUNDVALUE(QUANTITY value) {
        this.turnaroundvalue = value;
    }

}

==> eam-wshub-proxyclient-11.7-3-sources.jar: net/datastream/schemas/mp_fields/TURNAROUND_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;
import org.openapplications.oagis_segments.QUANTITY;


/**
 * <p>Java class for TURNAROUND_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="TURNAROUND_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}TURNAROUNDUOM"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}TURNAROUNDVALUE"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "TURNAROUND_Type", propOrder = {
    "turnarounduom",
    "turnaroundvalue"
})
public class TURNAROUND_Type {

    @XmlElement(name = "TURNAROUNDUOM", required = true)
    protected TURNAROUNDUOM turnarounduom;
    @XmlElement(name = "TURNAROUNDVALUE", required = true)
    protected QUANTITY turnaroundvalue;

    /**
     * Gets the value of the turnarounduom property.
     * 
     * @return
     *     possible object is
     *     {@link TURNAROUNDUOM }
     *     
     */
    public TURNAROUNDUOM getTURNAROUNDUOM() {
        return turnarounduom;
    }

    /**
     * Sets the value of the turnarounduom property.
     * 
     * @param value
     *     allowed object is
     *     {@link TURNAROUNDUOM }
     *     
     */
    public void setTURNAROUNDUOM(TURNAROUNDUOM value) {
        this.turnarounduom = value;
    }

    /**
     * Gets the value of the turnaroundvalue property.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getTURNAROUNDVALUE() {
        return turnaroundvalue;
    }

    /**
     * Sets the value of the turnaroundvalue property.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setTURNAROUNDVALUE(QUANTITY value) {
        this.turnaroundvalue = value;
    }

}
